g4f - gui
Description: A conversational AI system that listens, learns, and challenges

discord ~ discord.gg/qXA4Wf4Fsm
github ~ @xtekky/gpt4free

### Settings

Enable Dark Mode
Web Access with DuckDuckGo
Disable Conversation History
Hide System-prompt
Download generated images
Refine files with spaCy
Track usage
Report errors
System prompt
Input max. height
Speech recognition language
Enable Memory with Mem0
Mem0 API:
Custom Provider (Base Url):
Custom Provider:
Microsoft Designer in Bing:
Scroll to bottom